package com.graphaware.neo4j.utils;

import org.neo4j.graphdb.Node;
import org.neo4j.graphdb.Relationship;

/**
 * Static utility class for dealing with various aspects of deleting stuff from the database.
 */
public final class DeleteUtils {

    /**
     * Delete a node, but delete all its relationships first.
     * This method assumes a transaction is in progress.
     *
     * @param toDelete node to delete along with its relationships.
     * @return number of deleted relationships.
     */
    public static int deleteNodeAndRelationships(Node toDelete) {
        int result = 0;
        for (Relationship relationship : toDelete.getRelationships()) {
            relationship.delete();
            result++;
        }
        toDelete.delete();
        return result;
    }

    private DeleteUtils() {
    }
}
